# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Data-Compare
Version:	1.29
Release:	1.%{__distinit}%{__distvers}
Summary:	Compare perl data structures
# Some of the metadata files suggest GPL2 rather than GPL (any version)
# but the module is actually licensed "same as perl"
# See "COPYRIGHT and LICENCE" in lib/Data/Compare.pm
# See also: https://github.com/DrHyde/perl-modules-Data-Compare/issues/15
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Data-Compare
Source0:	https://cpan.metacpan.org/modules/by-module/Data/Data-Compare-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Clone) >= 0.43
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Find::Rule)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(JSON)
BuildRequires:	perl(Scalar::Properties)
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module compares arbitrary data structures to see if they are copies
of each other.

%prep
%setup -q -n Data-Compare-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license ARTISTIC.txt GPL2.txt
%doc CHANGELOG MAINTAINERS-NOTE
%dir %{perl_vendorlib}/Data/
%dir %{perl_vendorlib}/Data/Compare/
%dir %{perl_vendorlib}/Data/Compare/Plugins/
%doc %{perl_vendorlib}/Data/Compare/Plugins.pod
%{perl_vendorlib}/Data/Compare.pm
%{perl_vendorlib}/Data/Compare/Plugins/Scalar/
%{_mandir}/man3/Data::Compare.3*
%{_mandir}/man3/Data::Compare::Plugins.3*
%{_mandir}/man3/Data::Compare::Plugins::Scalar::Properties.3*

%changelog
* Sat Apr 22 2023 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Skip taint-mode tests if perl was built without taint support

* Wed Mar 15 2023 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Bug fix: undef values in hashes were treated incorrectly: need to check
    for existence, not definedness before comparing (GH#21)
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop NOTES and README files as they provide nothing useful to users

* Tue Nov  5 2019 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Fix bug when options are passed as a persistent hash from calling code and
    not an anonymous hash (GH#14)

* Thu Sep 19 2019 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Minor code quality improvements from Alberto Simõe
  - Reinstate check for cwd being inaccessible

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 1.25-13
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop explicit %%clean section
  - Drop legacy BuildRoot: and Group: tags

* Fri Aug 12 2016 Paul Howarth <paul@city-fan.org> - 1.25-5
- BR: perl-generators where available
- Simplify find command using -delete

* Thu Dec 11 2014 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Add tests and patch to use refaddr and reftype to 'do the right thing' when
    comparing objects that overload numification and stringification

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 1.24-10
- Classify buildreqs by usage
- Use %%license where possible

* Sat Apr  5 2014 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Bump the required JSON.pm version for tests - something's a bit broken
    around about v2.53
- Drop %%defattr, redundant since rpm 4.4

* Thu Sep 26 2013 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Add tests for really big data structures (not yet working)
  - Check for taint-mode less insanely
  - Don't delay loading File::Find::Rule (see CPAN RT#87554)

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 1.22-5
- BR: perl(constant)
- Drop buildreqs for Perl core modules that are not dual-lived
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> - 1.22-4
- Import from Fedora

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.22-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Jul 19 2011 Petr Sabata <contyk@redhat.com> - 1.22-2
- Perl mass rebuild

* Tue Jun  7 2011 Tom Callaway <spot@fedoraproject.org> - 1.22-1
- Update to 1.22
- Add Requires: perl(File::Find::Rule)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.21-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec 16 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.21-6
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.21-5
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.21-4
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.21-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.21-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Feb 12 2009 Ralf Corsépius <corsepiu@fedoraproject.org> - 1.21-1
- Upstream update
- Spec file massaging

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.17-2
- Rebuild for new perl

* Wed Nov 28 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.17-1
- 0.17

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.16-1.2
- Add BR: perl(Test::More)

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 0.16-1.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Sun Mar 18 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.16-1
- Update to 0.16

* Mon Feb 26 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.15-1
- Update to 0.15

* Sun Nov  5 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.14-2
- New BR: perl(Clone) is needed by t/deep-objects.t

* Sun Nov  5 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.14-1
- Update to 0.14

* Sun Apr 09 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.13-1
- First build
